// java wrapper for vtkOpenGLGPUVolumeRayCastMapper object
//

package vtk;
import vtk.*;

public class vtkOpenGLGPUVolumeRayCastMapper extends vtkGPUVolumeRayCastMapper
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void GetDepthImage_2(vtkImageData id0);
  public void GetDepthImage(vtkImageData id0)
    { GetDepthImage_2(id0); }

  private native void GetColorImage_3(vtkImageData id0);
  public void GetColorImage(vtkImageData id0)
    { GetColorImage_3(id0); }

  private native int GetCurrentPass_4();
  public int GetCurrentPass()
    { return GetCurrentPass_4(); }

  private native void SetNoiseGenerator_5(vtkImplicitFunction id0);
  public void SetNoiseGenerator(vtkImplicitFunction id0)
    { SetNoiseGenerator_5(id0); }

  private native void SetNoiseTextureSize_6(int id0,int id1);
  public void SetNoiseTextureSize(int id0,int id1)
    { SetNoiseTextureSize_6(id0,id1); }

  private native void SetNoiseTextureSize_7(int id0[]);
  public void SetNoiseTextureSize(int id0[])
    { SetNoiseTextureSize_7(id0); }

  private native void SetPartitions_8(int id0,int id1,int id2);
  public void SetPartitions(int id0,int id1,int id2)
    { SetPartitions_8(id0,id1,id2); }

  private native boolean PreLoadData_9(vtkRenderer id0,vtkVolume id1);
  public boolean PreLoadData(vtkRenderer id0,vtkVolume id1)
    { return PreLoadData_9(id0,id1); }

  public vtkOpenGLGPUVolumeRayCastMapper() { super(); }

  public vtkOpenGLGPUVolumeRayCastMapper(long id) { super(id); }
  public native long   VTKInit();

}
